#############################################################################################
#############################################################################################
##
## DEFINE BLACKBOX 
##
#############################################################################################
#############################################################################################

EXECUTABLES = $(EXECUTABLES:-) gpgconf git 

BLACKBOX_ROOT_DIR     =  $(PROJECT_ROOT)
BLACKBOX_BUILD_DIR    =  $(BLACKBOX_ROOT_DIR)build/blackbox
BLACKBOX_CONFIG_PATH  =  $(BLACKBOX_ROOT_DIR).blackbox
BLACKBOX_GPG_PATH	  =  $(shell gpgconf --list-dirs homedir)

# The default image of blackbox
# only local image is supported
BLACKBOX_IMAGE_NAME= blackbox_local_temp_image
BLACKBOX_IMAGE_HASH = $(shell git log --format="%h" -n 1)
BLACKBOX_IMAGE      = $(BLACKBOX_IMAGE_NAME):$(BLACKBOX_IMAGE_HASH)

define BLACKBOX_RUN_SCRIPT 
#!/bin/bash

function cleanup()
{    
  for FILE in $$(blackbox_list_files); do
    blackbox_edit_end $${FILE} || exit 1
  done
  exit 0
}

if [ "$$#" -ne 1 ]; then
  ## args are: open, close, run
  echo "Usage: $$0 open|close|run"
  exit 1
fi

## trap if arg is run
if [ "$$1" == "run" ]; then
  	# Intercepts the signal and then executes the command to encrypt.
  	trap cleanup INT TERM SIGTERM SIGUSR1
fi

if [ "$$1" == "open" ] || [ "$$1" == "run" ]; then
    echo "Opening files..."
	for FILE in $$(blackbox_list_files); do
	  blackbox_edit_start $${FILE} || exit 1
	done
fi 

if [ "$$1" == "close" ]; then
  echo "Closing files..."
  for FILE in $$(blackbox_list_files); do
	blackbox_edit_end $${FILE} || exit 1
  done
elif [ "$$1" == "run" ]; then
  echo "Running command..."
  while true; do
    sleep 1
  done

elif [ "$$1" == "open" ]; then
  exit 0  
    
else
  echo "Unknown command: $$1"
  exit 1
fi


endef

define BLACKBOX_DOCKERFILE 
FROM docker-registry.schukai.com:443/debian-bullseye-amd64-slim:snapshot  AS deb-builder

RUN apt-get update && apt-get install git make rubygems build-essential
RUN cd /opt/ && \
    git clone https://github.com/StackExchange/blackbox.git

RUN gem install fpm    

RUN cd /opt/blackbox && \
    make packages-deb

FROM docker-registry.schukai.com:443/debian-bullseye-amd64-slim:snapshot

RUN apt-get update && apt-get install git gnupg
RUN sed -i /NAME=/s/=.*/'="Blackbox"'/ /etc/container-release ;

COPY --from=deb-builder /root/debbuild-stack_blackbox/  /tmp/
RUN apt-get install /tmp/*.deb 
RUN mkdir /repos /root/.gnupg

VOLUME [ "/repos" ]
WORKDIR /repos 

COPY ./filesystem/bin /bin/

RUN chmod ugo+x /bin/run-blackbox.sh

ARG UNAME=dummy
ARG UID=1000
ARG GID=1000

RUN groupadd -g $$GID -o $$UNAME
RUN useradd -m -u $$UID -g $$GID -o -s /bin/bash $$UNAME


ENTRYPOINT [ "/bin/run-blackbox.sh" ]
endef