#############################################################################################
#############################################################################################
##
## INIT-WEBCOMPONENTS
##
#############################################################################################
#############################################################################################

# @see .PHONY https://www.gnu.org/software/make/manual/html_node/Phony-Targets.html#Phony-Targets
.PHONY: init-platform-part

# The default directories are defined in the 
# directories-standard.mk file, but all other 
# targets can define directories as well.

$(PROJECT_DIRECTORIES):
	$(foreach path,$(PROJECT_DIRECTORIES),\
    		$(shell $(MKDIR) -p $(path)))

## init standard project	
init-platform-part: $(PROJECT_DIRECTORIES) $(PROJECT_ROOT).gitignore $(PROJECT_ROOT)package.json $(PROJECT_ROOT)README.md  $(LICENSE_PATH)LICENSE 
	$(ECHOMARKER) "Run init-webapp"
	$(ECHO) "Done"

#############################################################################################
#############################################################################################
##
## LICENSE
##
#############################################################################################
#############################################################################################

export LICENSE_FILE_CONTENT
$(LICENSE_PATH)LICENSE:
	$(QUIET) $(ECHO) "$$LICENSE_FILE_CONTENT" >> $@


#############################################################################################
#############################################################################################
##
## README
##
#############################################################################################
#############################################################################################

export README_FILE_CONTENT
$(PROJECT_ROOT)README.md:
	$(QUIET) $(ECHO) "$$README_FILE_CONTENT" >> $@

#############################################################################################
#############################################################################################
##
## BUILD PACKAGE JSON
##
#############################################################################################
#############################################################################################
define PLATFORM_PARTS_BUILD_PACKAGE_CONTENT
{
  "name": "@alvine/$(COMPONENT_SLUG)",
  "version": "0.1.0",
  "description": "$(COMPONENT_NAME)",
  "repository": {
    "type": "git",
    "url": "https://gitlab.schukai.com/alvine/application/platform-apps/parts/$(COMPONENT_SLUG).git"
  },
  "scripts": {
    "build-and-publish": "script/build-and-publish.sh",
    "semantic-release": "semantic-release",
    "build": "vite --config ./vite.config.js build",
    "preview": "vite --config ./vite.config.js preview",
    "dev": "vite --config ./vite.config.js"
  },
  "type": "module",
  "author": "schukai GmbH",
  "license": "see LICENSE file",
  "dependencies": {
    "@schukai/component-form": "^3.3.1",
    "@schukai/component-notify": "^2.3.0",
    "@schukai/component-state": "^2.3.0",
    "@schukai/component-style": "^0.28.0",
    "@schukai/monster": "^3.12.1"
  },   
  "devDependencies": {
   "@peculiar/webcrypto": "^1.4.1",
      "@semantic-release/changelog": "^6.0.2",
      "@semantic-release/exec": "^6.0.3",
      "@semantic-release/git": "^10.0.1",
      "@semantic-release/gitlab": "^10.1.4",
      "@semantic-release/npm": "^9.0.2",
      "@vitejs/plugin-basic-ssl": "^1.0.1",
      "autoprefixer": "^10.4.13",
      "btoa": "^1.2.1",
      "c8": "^7.12.0",
      "chai": "^4.3.7",
      "chai-dom": "^1.11.0",
      "clean-jsdoc-theme": "^4.2.6",
      "cli-real-favicon": "^0.0.8",
      "create-polyfill-service-url": "^2.2.6",
      "crypt": "^0.0.2",
      "cssnano": "^5.1.14",
      "esbuild": "^0.17.8",
      "flow-bin": "^0.199.1",
      "fs": "^0.0.1-security",
      "glob": "^8.1.0",
      "graphviz": "^0.0.9",
      "jsdoc": "^4.0.0",
      "jsdoc-external-example": "github:volker-schukai/jsdoc-external-example",
      "jsdom": "^21.1.0",
      "jsdom-global": "^3.0.2",
      "mocha": "^10.2.0",
      "npm-check-updates": "^16.7.4",
      "postcss": "^8.4.21",
      "postcss-color-mod-function": "^3.0.3",
      "postcss-fluid": "^1.4.2",
      "postcss-for": "^2.1.1",
      "postcss-import": "^15.1.0",
      "postcss-mixins": "^9.0.4",
      "postcss-nesting": "^11.2.0",
      "postcss-normalize": "^10.0.1",
      "postcss-responsive-type": "^1.0.0",
      "postcss-strip-units": "^2.0.1",
      "process": "^0.11.10",
      "semantic-release": "^20.1.0",
      "sinon": "^15.0.1",
      "svgo": "^3.0.2",
      "url": "^0.11.0",
      "url-exist": "3.0.1",
      "util": "^0.12.5",
      "vite": "^4.1.1",
      "vite-plugin-banner": "^0.7.0",
      "vite-plugin-list-directory-contents": "^1.4.5",
      "vite-plugin-minify": "^1.5.2",
      "vite-plugin-mkcert": "^1.13.0",
      "vite-plugin-mpa": "^1.1.4" 
  }
}
endef

export PLATFORM_PARTS_BUILD_PACKAGE_CONTENT
$(PROJECT_ROOT)package.json:
	$(QUIET) $(ECHO) "$$PLATFORM_PARTS_BUILD_PACKAGE_CONTENT" >> $@

######
